==> liquidwar6-0.0.4beta.tar.gz: liquidwar6-0.0.4beta/src/lib/gfx/mod-gl/gl-menu/gl-menu.h <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6GFX_MOD_GL_MENU_H
#define LIQUIDWAR6GFX_MOD_GL_MENU_H

#include <ltdl.h>

#include "../../../sys/sys.h"
#include "../../../map/map.h"
#include "../mod-gl.h"
#include "../gl-utils/gl-utils.h"

typedef struct mod_gl_menu_backend_s
{
  void *menu_context;
  char *backend_name;

  void *(*init) (mod_gl_utils_context_t * utils_context);
  void (*quit) (mod_gl_utils_context_t * utils_context, void *menu_context);
  void (*display) (mod_gl_utils_context_t * utils_context, void *menu_context,
		   lw6gui_look_t * look, lw6gui_menu_t * menu);
  void (*pick_item) (mod_gl_utils_context_t * utils_context,
		     void *menu_context, lw6gui_look_t * look,
		     int *position, int *scroll,
		     lw6gui_menu_t * menu, int screen_x, int screen_y);
  int (*warp_mouse_on_menuitem) (mod_gl_utils_context_t * utils_context,
				 void *menu_context, lw6gui_look_t * look,
				 lw6gui_menu_t * menu, int position);
}
mod_gl_menu_backend_t;

/*
 * In api.c
 */
extern int mod_gl_menu_init (mod_gl_utils_context_t * utils_context,
			     mod_gl_menu_backend_t * backend);
extern void mod_gl_menu_quit (mod_gl_utils_context_t * utils_context,
			      mod_gl_menu_backend_t * backend);
extern void mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
				 mod_gl_menu_backend_t * backend,
				 lw6gui_look_t * look, lw6gui_menu_t * menu);
extern void mod_gl_menu_pick_item (mod_gl_utils_context_t * utils_context,
				   mod_gl_menu_backend_t * backend,
				   lw6gui_look_t * look,
				   int *position, int *scroll,
				   lw6gui_menu_t * menu, int screen_x,
				   int screen_y);
extern int mod_gl_menu_warp_mouse_on_menuitem (mod_gl_utils_context_t *
					       utils_context,
					       mod_gl_menu_backend_t *
					       backend, lw6gui_look_t * look,
					       lw6gui_menu_t * menu,
					       int position);

/*
 * In backend.c
 */
extern mod_gl_menu_backend_t
  * mod_gl_menu_create_backend (mod_gl_utils_context_t * utils_context,
				char *name);
extern void mod_gl_menu_destroy_backend (mod_gl_utils_context_t *
					 utils_context,
					 mod_gl_menu_backend_t * backend);

#endif

==> liquidwar6-0.0.5beta.tar.gz: liquidwar6-0.0.5beta/src/lib/gfx/mod-gl/gl-menu/gl-menu.h <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6GFX_MOD_GL_MENU_H
#define LIQUIDWAR6GFX_MOD_GL_MENU_H

#include <ltdl.h>

#include "../../../sys/sys.h"
#include "../../../map/map.h"
#include "../mod-gl.h"
#include "../gl-utils/gl-utils.h"

typedef struct mod_gl_menu_backend_s
{
  void *menu_context;
  char *backend_name;

  void *(*init) (mod_gl_utils_context_t * utils_context);
  void (*quit) (mod_gl_utils_context_t * utils_context, void *menu_context);
  void (*display) (mod_gl_utils_context_t * utils_context, void *menu_context,
		   lw6gui_look_t * look, lw6gui_menu_t * menu,
		   float progress);
  void (*pick_item) (mod_gl_utils_context_t * utils_context,
		     void *menu_context, lw6gui_look_t * look, int *position,
		     int *scroll, lw6gui_menu_t * menu, int screen_x,
		     int screen_y);
  int (*warp_mouse_on_menuitem) (mod_gl_utils_context_t * utils_context,
				 void *menu_context, lw6gui_look_t * look,
				 lw6gui_menu_t * menu, int position);
  void (*center) (mod_gl_utils_context_t * utils_context, void *menu_context,
		  lw6gui_look_t * look, lw6gui_menu_t * menu, int position);
}
mod_gl_menu_backend_t;

/*
 * In api.c
 */
extern int mod_gl_menu_init (mod_gl_utils_context_t * utils_context,
			     mod_gl_menu_backend_t * backend);
extern void mod_gl_menu_quit (mod_gl_utils_context_t * utils_context,
			      mod_gl_menu_backend_t * backend);
extern void mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
				 mod_gl_menu_backend_t * backend,
				 lw6gui_look_t * look, lw6gui_menu_t * menu,
				 float progress);
extern void mod_gl_menu_pick_item (mod_gl_utils_context_t * utils_context,
				   mod_gl_menu_backend_t * backend,
				   lw6gui_look_t * look, int *position,
				   int *scroll, lw6gui_menu_t * menu,
				   int screen_x, int screen_y);
extern int mod_gl_menu_warp_mouse_on_menuitem (mod_gl_utils_context_t *
					       utils_context,
					       mod_gl_menu_backend_t *
					       backend, lw6gui_look_t * look,
					       lw6gui_menu_t * menu,
					       int position);
extern void mod_gl_menu_center (mod_gl_utils_context_t * utils_context,
				mod_gl_menu_backend_t * backend,
				lw6gui_look_t * look, lw6gui_menu_t * menu,
				int position);

/*
 * In backend.c
 */
extern mod_gl_menu_backend_t
  * mod_gl_menu_create_backend (mod_gl_utils_context_t * utils_context,
				char *name);
extern void mod_gl_menu_destroy_backend (mod_gl_utils_context_t *
					 utils_context,
					 mod_gl_menu_backend_t * backend);

#endif
